@@ -271,8 +271,9 @@ class _XMLTestResult(_TextTestResult):
                 # Handle partial and partialmethod objects.
                 test_method = getattr(test_method, 'func', test_method)
                 _, self.lineno = inspect.getsourcelines(test_method)
-        except (AttributeError, TypeError):
-            # issue #188, #189, some frameworks can make test method opaque.
+        except (AttributeError, IOError, TypeError):
+            # issue #188, #189, #195
+            # some frameworks can make test method opaque.
             pass
 
         if self.showAll:
@@ -693,6 +694,9 @@ class _XMLTestResult(_TextTestResult):
                 msgLines.append(STDERR_LINE % error)
         # This is the extra magic to make sure all lines are str
         encoding = getattr(sys.stdout, 'encoding', 'utf-8')
+        if encoding is None:
+            encoding = 'utf-8'
+
         lines = []
         for line in msgLines:
             if not isinstance(line, str):
